@@ -34,18 +34,28 @@ pub struct Context {
 
 impl Context {
     /// Byte offset starting from the 0. (counted separately for each file)
-    fn offset(&self, span: Span) -> (Option<usize>, Option<usize>) {
+    fn offset(&self, span: Span) -> (Option<u32>, Option<u32>) {
+        if span.is_dummy() {
+            return (None, None);
+        }
+
         // We rename this to feel more comfortable while doing math.
         let start_offset = self.fm.start_pos;
 
-        if span.is_dummy() {
-            (None, None)
-        } else {
-            (
-                Some((span.lo.0 - start_offset.0) as _),
-                Some((span.hi.0 - start_offset.0) as _),
-            )
+        let mut start = span.lo.0 - start_offset.0;
+        let mut end = span.hi.0 - start_offset.0;
+
+        for mb in self.fm.multibyte_chars.iter() {
+            if mb.pos < span.lo {
+                start -= (mb.bytes - 1) as u32;
+            }
+
+            if mb.pos < span.hi {
+                end -= (mb.bytes - 1) as u32;
+            }
         }
+
+        (Some(start), Some(end))
     }
 
     fn line_col(&self, pos: BytePos) -> Option<LineCol> {
@@ -124,7 +134,7 @@ impl Context {
             start,
             end,
             loc,
-            range: if matches!(Flavor::current(), Flavor::Acorn) {
+            range: if matches!(Flavor::current(), Flavor::Acorn { .. }) {
                 match (start, end) {
                     (Some(start), Some(end)) => Some([start, end]),
                     _ => None,
@@ -154,7 +164,11 @@ where
 
     fn babelify(self, ctx: &Context) -> Self::Output {
         if T::parallel(self.len()) {
-            self.into_par_iter().map(|v| v.babelify(ctx)).collect()
+            let flavor = Flavor::current();
+
+            self.into_par_iter()
+                .map(|v| flavor.with(|| v.babelify(ctx)))
+                .collect()
         } else {
             self.into_iter().map(|v| v.babelify(ctx)).collect()
         }
